Optical physiology
==================



Plane Segmentation
------------------


.. _best_practice_plane_segmentation_image_mask_shape_against_ref_images:

Image Shape Consistency
~~~~~~~~~~~~~~~~~~~~~~~

The ``image_mask`` column of a ``PlaneSegmentation``, if specified, should have the same image shape as each item in the ``reference_images``.
